You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by st...@apache.org on 2015/01/02 15:42:24 UTC

svn commit: r1649050 - in /subversion/trunk/subversion/libsvn_fs_x: cached_data.c cached_data.h fs.h fs_x.c fs_x.h low_level.c low_level.h noderevs.c pack.c rep-cache.c rep-cache.h reps.c reps.h temp_serializer.c transaction.c verify.c

Author: stefan2
Date: Fri Jan  2 14:42:23 2015
New Revision: 1649050

URL: http://svn.apache.org/r1649050
Log:
In FSX, continue renaming global structs to meet our coding guidelines.
This is part of a series of search-replace changes.  

* subversion/libsvn_fs_x/fs.h
  (representation_t): Rename to ...
  (svn_fs_x__representation_t): ... this.
  (node_revision_t): Update references.

* subversion/libsvn_fs_x/cached_data.c
* subversion/libsvn_fs_x/cached_data.h
* subversion/libsvn_fs_x/fs_x.c
* subversion/libsvn_fs_x/fs_x.h
* subversion/libsvn_fs_x/low_level.c
* subversion/libsvn_fs_x/low_level.h
* subversion/libsvn_fs_x/noderevs.c
* subversion/libsvn_fs_x/pack.c
* subversion/libsvn_fs_x/rep-cache.c
* subversion/libsvn_fs_x/rep-cache.h
* subversion/libsvn_fs_x/reps.c
* subversion/libsvn_fs_x/reps.h
* subversion/libsvn_fs_x/temp_serializer.c
* subversion/libsvn_fs_x/transaction.c
* subversion/libsvn_fs_x/verify.c
  ():s/representation_t/svn_fs_x__representation_t/g

Modified:
    subversion/trunk/subversion/libsvn_fs_x/cached_data.c
    subversion/trunk/subversion/libsvn_fs_x/cached_data.h
    subversion/trunk/subversion/libsvn_fs_x/fs.h
    subversion/trunk/subversion/libsvn_fs_x/fs_x.c
    subversion/trunk/subversion/libsvn_fs_x/fs_x.h
    subversion/trunk/subversion/libsvn_fs_x/low_level.c
    subversion/trunk/subversion/libsvn_fs_x/low_level.h
    subversion/trunk/subversion/libsvn_fs_x/noderevs.c
    subversion/trunk/subversion/libsvn_fs_x/pack.c
    subversion/trunk/subversion/libsvn_fs_x/rep-cache.c
    subversion/trunk/subversion/libsvn_fs_x/rep-cache.h
    subversion/trunk/subversion/libsvn_fs_x/reps.c
    subversion/trunk/subversion/libsvn_fs_x/reps.h
    subversion/trunk/subversion/libsvn_fs_x/temp_serializer.c
    subversion/trunk/subversion/libsvn_fs_x/transaction.c
    subversion/trunk/subversion/libsvn_fs_x/verify.c

Modified: subversion/trunk/subversion/libsvn_fs_x/cached_data.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_fs_x/cached_data.c?rev=1649050&r1=1649049&r2=1649050&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_fs_x/cached_data.c (original)
+++ subversion/trunk/subversion/libsvn_fs_x/cached_data.c Fri Jan  2 14:42:23 2015
@@ -219,7 +219,7 @@ open_and_seek_revision(svn_fs_x__revisio
 static svn_error_t *
 open_and_seek_transaction(svn_fs_x__revision_file_t **file,
                           svn_fs_t *fs,
-                          representation_t *rep,
+                          svn_fs_x__representation_t *rep,
                           apr_pool_t *pool)
 {
   apr_off_t offset;
@@ -241,7 +241,7 @@ open_and_seek_transaction(svn_fs_x__revi
 static svn_error_t *
 open_and_seek_representation(svn_fs_x__revision_file_t **file_p,
                              svn_fs_t *fs,
-                             representation_t *rep,
+                             svn_fs_x__representation_t *rep,
                              apr_pool_t *pool)
 {
   if (svn_fs_x__is_revision(rep->id.change_set))
@@ -592,7 +592,7 @@ static svn_error_t *
 create_rep_state_body(rep_state_t **rep_state,
                       svn_fs_x__rep_header_t **rep_header,
                       shared_file_t **shared_file,
-                      representation_t *rep,
+                      svn_fs_x__representation_t *rep,
                       svn_fs_t *fs,
                       apr_pool_t *result_pool,
                       apr_pool_t *scratch_pool)
@@ -778,7 +778,7 @@ static svn_error_t *
 create_rep_state(rep_state_t **rep_state,
                  svn_fs_x__rep_header_t **rep_header,
                  shared_file_t **shared_file,
-                 representation_t *rep,
+                 svn_fs_x__representation_t *rep,
                  svn_fs_t *fs,
                  apr_pool_t *result_pool,
                  apr_pool_t *scratch_pool)
@@ -808,7 +808,7 @@ create_rep_state(rep_state_t **rep_state
 }
 
 svn_error_t *
-svn_fs_x__check_rep(representation_t *rep,
+svn_fs_x__check_rep(svn_fs_x__representation_t *rep,
                     svn_fs_t *fs,
                     apr_pool_t *scratch_pool)
 {
@@ -852,7 +852,7 @@ svn_fs_x__check_rep(representation_t *re
 svn_error_t *
 svn_fs_x__rep_chain_length(int *chain_length,
                            int *shard_count,
-                           representation_t *rep,
+                           svn_fs_x__representation_t *rep,
                            svn_fs_t *fs,
                            apr_pool_t *scratch_pool)
 {
@@ -873,7 +873,7 @@ svn_fs_x__rep_chain_length(int *chain_le
   /* Check whether the length of the deltification chain is acceptable.
    * Otherwise, shared reps may form a non-skipping delta chain in
    * extreme cases. */
-  representation_t base_rep = *rep;
+  svn_fs_x__representation_t base_rep = *rep;
 
   /* re-use open files between iterations */
   shared_file_t *file_hint = NULL;
@@ -939,7 +939,7 @@ struct rep_read_baton
   svn_fs_t *fs;
 
   /* Representation to read. */
-  representation_t rep;
+  svn_fs_x__representation_t rep;
 
   /* If not NULL, this is the base for the first delta window in rs_list */
   svn_stringbuf_t *base_window;
@@ -1231,10 +1231,10 @@ build_rep_list(apr_array_header_t **list
                svn_stringbuf_t **window_p,
                rep_state_t **src_state,
                svn_fs_t *fs,
-               representation_t *first_rep,
+               svn_fs_x__representation_t *first_rep,
                apr_pool_t *pool)
 {
-  representation_t rep;
+  svn_fs_x__representation_t rep;
   rep_state_t *rs = NULL;
   svn_fs_x__rep_header_t *rep_header;
   svn_boolean_t is_cached = FALSE;
@@ -1310,7 +1310,7 @@ build_rep_list(apr_array_header_t **list
 static svn_error_t *
 rep_read_get_baton(struct rep_read_baton **rb_p,
                    svn_fs_t *fs,
-                   representation_t *rep,
+                   svn_fs_x__representation_t *rep,
                    svn_fs_x__pair_cache_key_t fulltext_cache_key,
                    apr_pool_t *pool)
 {
@@ -2142,7 +2142,7 @@ rep_read_contents(void *baton,
 svn_error_t *
 svn_fs_x__get_contents(svn_stream_t **contents_p,
                        svn_fs_t *fs,
-                       representation_t *rep,
+                       svn_fs_x__representation_t *rep,
                        svn_boolean_t cache_fulltext,
                        apr_pool_t *pool)
 {
@@ -2231,7 +2231,7 @@ svn_fs_x__try_process_file_contents(svn_
                                     void* baton,
                                     apr_pool_t *pool)
 {
-  representation_t *rep = noderev->data_rep;
+  svn_fs_x__representation_t *rep = noderev->data_rep;
   if (rep)
     {
       svn_fs_x__data_t *ffd = fs->fsap_data;
@@ -2734,7 +2734,7 @@ svn_fs_x__get_proplist(apr_hash_t **prop
   else if (noderev->prop_rep)
     {
       svn_fs_x__data_t *ffd = fs->fsap_data;
-      representation_t *rep = noderev->prop_rep;
+      svn_fs_x__representation_t *rep = noderev->prop_rep;
       svn_fs_x__pair_cache_key_t key = { 0 };
 
       key.revision = svn_fs_x__get_revnum(rep->id.change_set);

Modified: subversion/trunk/subversion/libsvn_fs_x/cached_data.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_fs_x/cached_data.h?rev=1649050&r1=1649049&r2=1649050&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_fs_x/cached_data.h (original)
+++ subversion/trunk/subversion/libsvn_fs_x/cached_data.h Fri Jan  2 14:42:23 2015
@@ -59,7 +59,7 @@ svn_fs_x__rev_get_root(svn_fs_x__id_t *r
 /* Verify that representation REP in FS can be accessed.
    Do any allocations in SCRATCH_POOL. */
 svn_error_t *
-svn_fs_x__check_rep(representation_t *rep,
+svn_fs_x__check_rep(svn_fs_x__representation_t *rep,
                     svn_fs_t *fs,
                     apr_pool_t *scratch_pool);
 
@@ -70,7 +70,7 @@ svn_fs_x__check_rep(representation_t *re
 svn_error_t *
 svn_fs_x__rep_chain_length(int *chain_length,
                            int *shard_count,
-                           representation_t *rep,
+                           svn_fs_x__representation_t *rep,
                            svn_fs_t *fs,
                            apr_pool_t *scratch_pool);
 
@@ -82,7 +82,7 @@ svn_fs_x__rep_chain_length(int *chain_le
 svn_error_t *
 svn_fs_x__get_contents(svn_stream_t **contents_p,
                        svn_fs_t *fs,
-                       representation_t *rep,
+                       svn_fs_x__representation_t *rep,
                        svn_boolean_t cache_fulltext,
                        apr_pool_t *pool);
 

Modified: subversion/trunk/subversion/libsvn_fs_x/fs.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_fs_x/fs.h?rev=1649050&r1=1649049&r2=1649050&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_fs_x/fs.h (original)
+++ subversion/trunk/subversion/libsvn_fs_x/fs.h Fri Jan  2 14:42:23 2015
@@ -440,7 +440,7 @@ typedef struct svn_fs_x__transaction_t
 /*** Representation ***/
 /* If you add fields to this, check to see if you need to change
  * svn_fs_x__rep_copy. */
-typedef struct representation_t
+typedef struct svn_fs_x__representation_t
 {
   /* Checksums digests for the contents produced by this representation.
      This checksum is for the contents the rep shows to consumers,
@@ -467,7 +467,7 @@ typedef struct representation_t
   /* The size of the fulltext of the representation. */
   svn_filesize_t expanded_size;
 
-} representation_t;
+} svn_fs_x__representation_t;
 
 
 /*** Node-Revision ***/
@@ -506,11 +506,11 @@ typedef struct node_revision_t
 
   /* representation key for this node's properties.  may be NULL if
      there are no properties.  */
-  representation_t *prop_rep;
+  svn_fs_x__representation_t *prop_rep;
 
   /* representation for this node's data.  may be NULL if there is
      no data. */
-  representation_t *data_rep;
+  svn_fs_x__representation_t *data_rep;
 
   /* path at which this node first came into existence.  */
   const char *created_path;

Modified: subversion/trunk/subversion/libsvn_fs_x/fs_x.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_fs_x/fs_x.c?rev=1649050&r1=1649049&r2=1649050&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_fs_x/fs_x.c (original)
+++ subversion/trunk/subversion/libsvn_fs_x/fs_x.c Fri Jan  2 14:42:23 2015
@@ -693,8 +693,8 @@ svn_fs_x__file_length(svn_filesize_t *le
 }
 
 svn_boolean_t
-svn_fs_x__file_text_rep_equal(representation_t *a,
-                              representation_t *b)
+svn_fs_x__file_text_rep_equal(svn_fs_x__representation_t *a,
+                              svn_fs_x__representation_t *b)
 {
   svn_boolean_t a_empty = a == NULL || a->expanded_size == 0;
   svn_boolean_t b_empty = b == NULL || b->expanded_size == 0;
@@ -725,8 +725,8 @@ svn_fs_x__prop_rep_equal(svn_boolean_t *
                          svn_boolean_t strict,
                          apr_pool_t *scratch_pool)
 {
-  representation_t *rep_a = a->prop_rep;
-  representation_t *rep_b = b->prop_rep;
+  svn_fs_x__representation_t *rep_a = a->prop_rep;
+  svn_fs_x__representation_t *rep_b = b->prop_rep;
   apr_hash_t *proplist_a;
   apr_hash_t *proplist_b;
 
@@ -810,11 +810,11 @@ svn_fs_x__file_checksum(svn_checksum_t *
   return SVN_NO_ERROR;
 }
 
-representation_t *
-svn_fs_x__rep_copy(representation_t *rep,
+svn_fs_x__representation_t *
+svn_fs_x__rep_copy(svn_fs_x__representation_t *rep,
                    apr_pool_t *pool)
 {
-  representation_t *rep_new;
+  svn_fs_x__representation_t *rep_new;
 
   if (rep == NULL)
     return NULL;

Modified: subversion/trunk/subversion/libsvn_fs_x/fs_x.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_fs_x/fs_x.h?rev=1649050&r1=1649049&r2=1649050&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_fs_x/fs_x.h (original)
+++ subversion/trunk/subversion/libsvn_fs_x/fs_x.h Fri Jan  2 14:42:23 2015
@@ -86,8 +86,8 @@ svn_error_t *svn_fs_x__file_length(svn_f
 
 /* Return TRUE if the representations in A and B have equal contents, else
    return FALSE. */
-svn_boolean_t svn_fs_x__file_text_rep_equal(representation_t *a,
-                                            representation_t *b);
+svn_boolean_t svn_fs_x__file_text_rep_equal(svn_fs_x__representation_t *a,
+                                            svn_fs_x__representation_t *b);
 
 /* Set *EQUAL to TRUE if the property representations in A and B within FS
    have equal contents, else set it to FALSE.  If STRICT is not set, allow
@@ -102,7 +102,7 @@ svn_error_t *svn_fs_x__prop_rep_equal(sv
 
 
 /* Return a copy of the representation REP allocated from POOL. */
-representation_t *svn_fs_x__rep_copy(representation_t *rep,
+svn_fs_x__representation_t *svn_fs_x__rep_copy(svn_fs_x__representation_t *rep,
                                      apr_pool_t *pool);
 
 

Modified: subversion/trunk/subversion/libsvn_fs_x/low_level.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_fs_x/low_level.c?rev=1649050&r1=1649049&r2=1649050&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_fs_x/low_level.c (original)
+++ subversion/trunk/subversion/libsvn_fs_x/low_level.c Fri Jan  2 14:42:23 2015
@@ -238,12 +238,12 @@ read_header_block(apr_hash_t **headers,
 }
 
 svn_error_t *
-svn_fs_x__parse_representation(representation_t **rep_p,
+svn_fs_x__parse_representation(svn_fs_x__representation_t **rep_p,
                                svn_stringbuf_t *text,
                                apr_pool_t *result_pool,
                                apr_pool_t *scratch_pool)
 {
-  representation_t *rep;
+  svn_fs_x__representation_t *rep;
   char *str;
   apr_int64_t val;
   char *string = text->data;
@@ -325,7 +325,7 @@ svn_fs_x__parse_representation(represent
 /* Wrap read_rep_offsets_body(), extracting its TXN_ID from our NODEREV_ID,
    and adding an error message. */
 static svn_error_t *
-read_rep_offsets(representation_t **rep_p,
+read_rep_offsets(svn_fs_x__representation_t **rep_p,
                  char *string,
                  const svn_fs_x__id_t *noderev_id,
                  apr_pool_t *result_pool,
@@ -595,7 +595,7 @@ format_digest(const unsigned char *diges
 }
 
 svn_stringbuf_t *
-svn_fs_x__unparse_representation(representation_t *rep,
+svn_fs_x__unparse_representation(svn_fs_x__representation_t *rep,
                                  svn_boolean_t mutable_rep_truncated,
                                  apr_pool_t *result_pool,
                                  apr_pool_t *scratch_pool)

Modified: subversion/trunk/subversion/libsvn_fs_x/low_level.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_fs_x/low_level.h?rev=1649050&r1=1649049&r2=1649050&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_fs_x/low_level.h (original)
+++ subversion/trunk/subversion/libsvn_fs_x/low_level.h Fri Jan  2 14:42:23 2015
@@ -81,7 +81,7 @@ svn_fs_x__unparse_footer(apr_off_t l2p_o
    into *REP_P.  TEXT will be invalidated by this call.  Allocate *REP_P in
    RESULT_POOL and use SCRATCH_POOL for temporaries. */
 svn_error_t *
-svn_fs_x__parse_representation(representation_t **rep_p,
+svn_fs_x__parse_representation(svn_fs_x__representation_t **rep_p,
                                svn_stringbuf_t *text,
                                apr_pool_t *result_pool,
                                apr_pool_t *scratch_pool);
@@ -92,7 +92,7 @@ svn_fs_x__parse_representation(represent
  * If MAY_BE_CORRUPT is true, guard for NULL when constructing the string.
  * Allocate the result in RESULT_POOL and temporaries in SCRATCH_POOL. */
 svn_stringbuf_t *
-svn_fs_x__unparse_representation(representation_t *rep,
+svn_fs_x__unparse_representation(svn_fs_x__representation_t *rep,
                                  svn_boolean_t mutable_rep_truncated,
                                  apr_pool_t *result_pool,
                                  apr_pool_t *scratch_pool);

Modified: subversion/trunk/subversion/libsvn_fs_x/noderevs.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_fs_x/noderevs.c?rev=1649050&r1=1649049&r2=1649050&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_fs_x/pack.c (original)
+++ subversion/trunk/subversion/libsvn_fs_x/pack.c Fri Jan  2 14:42:23 2015
@@ -1224,7 +1224,7 @@ write_reps_containers(pack_context_t *co
   /* copy all items in strict order */
   for (i = entries->nelts-1; i >= 0; --i)
     {
-      representation_t representation = { 0 };
+      svn_fs_x__representation_t representation = { 0 };
       svn_stringbuf_t *contents;
       svn_stream_t *stream;
       apr_size_t list_index;

Modified: subversion/trunk/subversion/libsvn_fs_x/rep-cache.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_fs_x/rep-cache.c?rev=1649050&r1=1649049&r2=1649050&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_fs_x/rep-cache.c (original)
+++ subversion/trunk/subversion/libsvn_fs_x/rep-cache.c Fri Jan  2 14:42:23 2015
@@ -141,7 +141,7 @@ svn_error_t *
 svn_fs_x__walk_rep_reference(svn_fs_t *fs,
                              svn_revnum_t start,
                              svn_revnum_t end,
-                             svn_error_t *(*walker)(representation_t *,
+                             svn_error_t *(*walker)(svn_fs_x__representation_t *,
                                                     void *,
                                                     svn_fs_t *,
                                                     apr_pool_t *),
@@ -183,7 +183,7 @@ svn_fs_x__walk_rep_reference(svn_fs_t *f
   SVN_ERR(svn_sqlite__step(&have_row, stmt));
   while (have_row)
     {
-      representation_t *rep;
+      svn_fs_x__representation_t *rep;
       const char *sha1_digest;
       svn_error_t *err;
       svn_checksum_t *checksum;
@@ -200,7 +200,7 @@ svn_fs_x__walk_rep_reference(svn_fs_t *f
             return svn_error_compose_create(err, svn_sqlite__reset(stmt));
         }
 
-      /* Construct a representation_t. */
+      /* Construct a svn_fs_x__representation_t. */
       rep = apr_pcalloc(iterpool, sizeof(*rep));
       sha1_digest = svn_sqlite__column_text(stmt, 0, iterpool);
       err = svn_checksum_parse_hex(&checksum, svn_checksum_sha1,
@@ -234,7 +234,7 @@ svn_fs_x__walk_rep_reference(svn_fs_t *f
    If you extend this function, check the callsite to see if you have
    to make it not-ignore additional error codes.  */
 svn_error_t *
-svn_fs_x__get_rep_reference(representation_t **rep,
+svn_fs_x__get_rep_reference(svn_fs_x__representation_t **rep,
                             svn_fs_t *fs,
                             svn_checksum_t *checksum,
                             apr_pool_t *pool)
@@ -291,7 +291,7 @@ svn_fs_x__get_rep_reference(representati
 
 svn_error_t *
 svn_fs_x__set_rep_reference(svn_fs_t *fs,
-                            representation_t *rep,
+                            svn_fs_x__representation_t *rep,
                             apr_pool_t *pool)
 {
   svn_fs_x__data_t *ffd = fs->fsap_data;
@@ -322,7 +322,7 @@ svn_fs_x__set_rep_reference(svn_fs_t *fs
   err = svn_sqlite__insert(NULL, stmt);
   if (err)
     {
-      representation_t *old_rep;
+      svn_fs_x__representation_t *old_rep;
 
       if (err->apr_err != SVN_ERR_SQLITE_CONSTRAINT)
         return svn_error_trace(err);

Modified: subversion/trunk/subversion/libsvn_fs_x/rep-cache.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_fs_x/rep-cache.h?rev=1649050&r1=1649049&r2=1649050&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_fs_x/rep-cache.h (original)
+++ subversion/trunk/subversion/libsvn_fs_x/rep-cache.h Fri Jan  2 14:42:23 2015
@@ -51,7 +51,7 @@ svn_error_t *
 svn_fs_x__walk_rep_reference(svn_fs_t *fs,
                              svn_revnum_t start,
                              svn_revnum_t end,
-                             svn_error_t *(*walker)(representation_t *rep,
+                             svn_error_t *(*walker)(svn_fs_x__representation_t *rep,
                                                     void *walker_baton,
                                                     svn_fs_t *fs,
                                                     apr_pool_t *scratch_pool),
@@ -65,7 +65,7 @@ svn_fs_x__walk_rep_reference(svn_fs_t *f
    opened, just set *REP to NULL.  Returns SVN_ERR_FS_CORRUPT if
    a reference beyond HEAD is detected. */
 svn_error_t *
-svn_fs_x__get_rep_reference(representation_t **rep,
+svn_fs_x__get_rep_reference(svn_fs_x__representation_t **rep,
                             svn_fs_t *fs,
                             svn_checksum_t *checksum,
                             apr_pool_t *pool);
@@ -77,7 +77,7 @@ svn_fs_x__get_rep_reference(representati
    If the rep cache database has not been opened, this may be a no op. */
 svn_error_t *
 svn_fs_x__set_rep_reference(svn_fs_t *fs,
-                            representation_t *rep,
+                            svn_fs_x__representation_t *rep,
                             apr_pool_t *pool);
 
 /* Delete from the cache all reps corresponding to revisions younger

Modified: subversion/trunk/subversion/libsvn_fs_x/reps.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_fs_x/reps.c?rev=1649050&r1=1649049&r2=1649050&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_fs_x/reps.c (original)
+++ subversion/trunk/subversion/libsvn_fs_x/reps.c Fri Jan  2 14:42:23 2015
@@ -401,7 +401,7 @@ svn_fs_x__reps_builder_create(svn_fs_t *
 
 svn_error_t *
 svn_fs_x__reps_add_base(svn_fs_x__reps_builder_t *builder,
-                        representation_t *rep,
+                        svn_fs_x__representation_t *rep,
                         int priority,
                         apr_pool_t *scratch_pool)
 {

Modified: subversion/trunk/subversion/libsvn_fs_x/reps.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_fs_x/reps.h?rev=1649050&r1=1649049&r2=1649050&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_fs_x/reps.h (original)
+++ subversion/trunk/subversion/libsvn_fs_x/reps.h Fri Jan  2 14:42:23 2015
@@ -91,7 +91,7 @@ svn_fs_x__reps_builder_create(svn_fs_t *
  */
 svn_error_t *
 svn_fs_x__reps_add_base(svn_fs_x__reps_builder_t *builder,
-                        representation_t *rep,
+                        svn_fs_x__representation_t *rep,
                         int priority,
                         apr_pool_t *scratch_pool);
 

Modified: subversion/trunk/subversion/libsvn_fs_x/temp_serializer.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_fs_x/temp_serializer.c?rev=1649050&r1=1649049&r2=1649050&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_fs_x/temp_serializer.c (original)
+++ subversion/trunk/subversion/libsvn_fs_x/temp_serializer.c Fri Jan  2 14:42:23 2015
@@ -134,9 +134,9 @@ deserialize_svn_string(void *buffer, svn
  */
 static void
 serialize_representation(svn_temp_serializer__context_t *context,
-                         representation_t * const *representation)
+                         svn_fs_x__representation_t * const *representation)
 {
-  const representation_t * rep = *representation;
+  const svn_fs_x__representation_t * rep = *representation;
   if (rep == NULL)
     return;
 

Modified: subversion/trunk/subversion/libsvn_fs_x/transaction.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_fs_x/transaction.c?rev=1649050&r1=1649049&r2=1649050&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_fs_x/verify.c (original)
+++ subversion/trunk/subversion/libsvn_fs_x/verify.c Fri Jan  2 14:42:23 2015
@@ -58,7 +58,7 @@ typedef struct verify_walker_baton_t
 /* Used by svn_fs_x__verify().
    Implements svn_fs_x__walk_rep_reference().walker.  */
 static svn_error_t *
-verify_walker(representation_t *rep,
+verify_walker(svn_fs_x__representation_t *rep,
               void *baton,
               svn_fs_t *fs,
               apr_pool_t *scratch_pool)
--- subversion/trunk/subversion/libsvn_fs_x/noderevs.c (original)
+++ subversion/trunk/subversion/libsvn_fs_x/noderevs.c Fri Jan  2 14:42:23 2015
@@ -51,7 +51,7 @@
 
 /* Our internal representation of an representation.
  */
-typedef struct binary_representation_t
+typedef struct binary_svn_fs_x__representation_t
 {
   /* Checksums digests for the contents produced by this representation.
      If has_sha1 is FALSE, sha1_digest is not being used. */
@@ -69,7 +69,7 @@ typedef struct binary_representation_t
   /* The size of the fulltext of the representation. If this is 0,
    * the fulltext size is equal to representation size in the rev file, */
   svn_filesize_t expanded_size;
-} binary_representation_t;
+} binary_svn_fs_x__representation_t;
 
 /* Our internal representation of a node_revision_t.
  * 
@@ -151,14 +151,14 @@ struct svn_fs_x__noderevs_t
   /* During construction, maps a full binary_id_t to an index into IDS */
   apr_hash_t *ids_dict;
 
   /* During construction, maps a full binary_representation_t to an index
    * into REPS. */
   apr_hash_t *reps_dict;
 
   /* array of binary_id_t */
   apr_array_header_t *ids;
 
-  /* array of binary_representation_t */
+  /* array of binary_svn_fs_x__representation_t */
   apr_array_header_t *reps;
 
   /* array of binary_noderev_t. */
@@ -179,7 +179,7 @@ svn_fs_x__noderevs_create(int initial_co
   noderevs->ids
     = apr_array_make(pool, 2 * initial_count, sizeof(svn_fs_x__id_t));
   noderevs->reps
-    = apr_array_make(pool, 2 * initial_count, sizeof(binary_representation_t));
+    = apr_array_make(pool, 2 * initial_count, sizeof(binary_svn_fs_x__representation_t));
   noderevs->noderevs
     = apr_array_make(pool, initial_count, sizeof(binary_noderev_t));
 
@@ -219,9 +219,9 @@ store_id(apr_array_header_t *ids,
 static int
 store_representation(apr_array_header_t *reps,
                      apr_hash_t *dict,
-                     const representation_t *rep)
+                     const svn_fs_x__representation_t *rep)
 {
-  binary_representation_t binary_rep = { 0 };
+  binary_svn_fs_x__representation_t binary_rep = { 0 };
   int idx;
   void *idx_void;
 
@@ -239,7 +239,7 @@ store_representation(apr_array_header_t
   idx = (int)(apr_uintptr_t)idx_void;
   if (idx == 0)
     {
-      APR_ARRAY_PUSH(reps, binary_representation_t) = binary_rep;
+      APR_ARRAY_PUSH(reps, binary_svn_fs_x__representation_t) = binary_rep;
       idx = reps->nelts;
       apr_hash_set(dict, reps->elts + (idx-1) * reps->elt_size,
                    reps->elt_size, (void*)(apr_uintptr_t)idx);
@@ -354,16 +354,16 @@ get_id(svn_fs_x__id_t *id,
   return SVN_NO_ERROR;
 }
 
 /* Create a representation_t in *REP, allocated in POOL based on the
  * representation stored at index IDX in REPS.
  */
 static svn_error_t *
-get_representation(representation_t **rep,
+get_representation(svn_fs_x__representation_t **rep,
                    const apr_array_header_t *reps,
                    int idx,
                    apr_pool_t *pool)
 {
-  binary_representation_t *binary_rep;
+  binary_svn_fs_x__representation_t *binary_rep;
 
   /* handle NULL representations  */
   if (idx == 0)
@@ -380,7 +380,7 @@ get_representation(representation_t **re
                              idx, reps->nelts);
 
   /* no translation required. Just duplicate the info */
-  binary_rep = &APR_ARRAY_IDX(reps, idx - 1, binary_representation_t);
+  binary_rep = &APR_ARRAY_IDX(reps, idx - 1, binary_svn_fs_x__representation_t);
 
   *rep = apr_pcalloc(pool, sizeof(**rep));
   (*rep)->has_sha1 = binary_rep->has_sha1;
@@ -515,8 +515,8 @@ write_reps(svn_packed__int_stream_t *rep
   int i;
   for (i = 0; i < reps->nelts; ++i)
     {
-      binary_representation_t *rep
-        = &APR_ARRAY_IDX(reps, i, binary_representation_t);
+      binary_svn_fs_x__representation_t *rep
+        = &APR_ARRAY_IDX(reps, i, binary_svn_fs_x__representation_t);
 
       svn_packed__add_uint(rep_stream, rep->has_sha1);
 
@@ -616,7 +616,7 @@ svn_fs_x__write_noderevs_container(svn_s
   return SVN_NO_ERROR;
 }
 
 /* Allocate a representation_t array in POOL and return it in *REPS_P.
  * Deserialize the data in REP_STREAM and DIGEST_STREAM and store the
  * resulting representations into the *REPS_P.
  */
@@ -633,11 +633,11 @@ read_reps(apr_array_header_t **reps_p,
   apr_size_t count
     = svn_packed__int_count(svn_packed__first_int_substream(rep_stream));
   apr_array_header_t *reps
-    = apr_array_make(pool, (int)count, sizeof(binary_representation_t));
+    = apr_array_make(pool, (int)count, sizeof(binary_svn_fs_x__representation_t));
 
   for (i = 0; i < count; ++i)
     {
-      binary_representation_t rep;
+      binary_svn_fs_x__representation_t rep;
 
       rep.has_sha1 = (svn_boolean_t)svn_packed__get_uint(rep_stream);
 
@@ -672,7 +672,7 @@ read_reps(apr_array_header_t **reps_p,
           memcpy(rep.sha1_digest, bytes, sizeof(rep.sha1_digest));
         }
 
-      APR_ARRAY_PUSH(reps, binary_representation_t) = rep;
+      APR_ARRAY_PUSH(reps, binary_svn_fs_x__representation_t) = rep;
     }
 
   *reps_p = reps;
@@ -151,14 +151,14 @@ struct svn_fs_x__noderevs_t
   apr_hash_t *ids_dict;
 
-  /* During construction, maps a full binary_representation_t to an index
+  /* During construction, maps a full binary_svn_fs_x__representation_t to an index
    * into REPS. */
   apr_hash_t *reps_dict;
@@ -354,16 +354,16 @@ get_id(svn_fs_x__id_t *id,
 }
 
-/* Create a representation_t in *REP, allocated in POOL based on the
+/* Create a svn_fs_x__representation_t in *REP, allocated in POOL based on the
  * representation stored at index IDX in REPS.
  */
@@ -616,7 +616,7 @@ svn_fs_x__write_noderevs_container(svn_s
 }
 
-/* Allocate a representation_t array in POOL and return it in *REPS_P.
+/* Allocate a svn_fs_x__representation_t array in POOL and return it in *REPS_P.
  * Deserialize the data in REP_STREAM and DIGEST_STREAM and store the
  * resulting representations into the *REPS_P.

Modified: subversion/trunk/subversion/libsvn_fs_x/pack.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_fs_x/pack.c?rev=1649050&r1=1649049&r2=1649050&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_fs_x/transaction.c (original)
+++ subversion/trunk/subversion/libsvn_fs_x/transaction.c Fri Jan  2 14:42:23 2015
@@ -1665,7 +1665,7 @@ svn_fs_x__set_entry(svn_fs_t *fs,
                     svn_node_kind_t kind,
                     apr_pool_t *pool)
 {
-  representation_t *rep = parent_noderev->data_rep;
+  svn_fs_x__representation_t *rep = parent_noderev->data_rep;
   const char *filename
     = svn_fs_x__path_txn_node_children(fs, &parent_noderev->noderev_id, pool);
   apr_file_t *file;
@@ -1899,7 +1899,7 @@ shards_spanned(int *spanned,
    base representation will be returned.  Perform temporary allocations
    in *POOL. */
 static svn_error_t *
-choose_delta_base(representation_t **rep,
+choose_delta_base(svn_fs_x__representation_t **rep,
                   svn_fs_t *fs,
                   node_revision_t *noderev,
                   svn_boolean_t props,
@@ -2063,7 +2063,7 @@ rep_write_get_baton(struct rep_write_bat
   svn_fs_x__data_t *ffd = fs->fsap_data;
   struct rep_write_baton *b;
   apr_file_t *file;
-  representation_t *base_rep;
+  svn_fs_x__representation_t *base_rep;
   svn_stream_t *source;
   svn_txdelta_window_handler_t wh;
   void *whb;
@@ -2145,14 +2145,14 @@ rep_write_get_baton(struct rep_write_bat
    if rep sharing has been disabled for FS, NULL will be returned.  Since
    there may be new duplicate representations within the same uncommitted
    revision, those can be passed in REPS_HASH (maps a sha1 digest onto
-   representation_t*), otherwise pass in NULL for REPS_HASH.
+   svn_fs_x__representation_t*), otherwise pass in NULL for REPS_HASH.
    Use RESULT_POOL for *OLD_REP  allocations and SCRATCH_POOL for temporaries.
    The lifetime of *OLD_REP is limited by both, RESULT_POOL and REP lifetime.
  */
 static svn_error_t *
-get_shared_rep(representation_t **old_rep,
+get_shared_rep(svn_fs_x__representation_t **old_rep,
                svn_fs_t *fs,
-               representation_t *rep,
+               svn_fs_x__representation_t *rep,
                apr_hash_t *reps_hash,
                apr_pool_t *result_pool,
                apr_pool_t *scratch_pool)
@@ -2249,7 +2249,7 @@ get_shared_rep(representation_t **old_re
  * Use POOL for allocations.
  */
 static svn_error_t *
-digests_final(representation_t *rep,
+digests_final(svn_fs_x__representation_t *rep,
               const svn_checksum_ctx_t *md5_ctx,
               const svn_checksum_ctx_t *sha1_ctx,
               apr_pool_t *pool)
@@ -2273,8 +2273,8 @@ static svn_error_t *
 rep_write_contents_close(void *baton)
 {
   struct rep_write_baton *b = baton;
-  representation_t *rep;
-  representation_t *old_rep;
+  svn_fs_x__representation_t *rep;
+  svn_fs_x__representation_t *old_rep;
   apr_off_t offset;
   apr_int64_t txn_id;
 
@@ -2534,7 +2534,7 @@ write_directory_to_stream(svn_stream_t *
    Perform temporary allocations in SCRATCH_POOL.
  */
 static svn_error_t *
-write_container_delta_rep(representation_t *rep,
+write_container_delta_rep(svn_fs_x__representation_t *rep,
                           apr_file_t *file,
                           void *collection,
                           collection_writer_t writer,
@@ -2552,8 +2552,8 @@ write_container_delta_rep(representation
 
   svn_stream_t *file_stream;
   svn_stream_t *stream;
-  representation_t *base_rep;
-  representation_t *old_rep;
+  svn_fs_x__representation_t *base_rep;
+  svn_fs_x__representation_t *old_rep;
   svn_fs_x__p2l_entry_t entry;
   svn_stream_t *source;
   svn_fs_x__rep_header_t header = { 0 };
@@ -2887,7 +2887,7 @@ write_final_rev(svn_fs_x__id_t *new_id_p
           && svn_fs_x__get_revnum(noderev->data_rep->id.change_set) == rev)
         {
           SVN_ERR_ASSERT(reps_to_cache && reps_pool);
-          APR_ARRAY_PUSH(reps_to_cache, representation_t *)
+          APR_ARRAY_PUSH(reps_to_cache, svn_fs_x__representation_t *)
             = svn_fs_x__rep_copy(noderev->data_rep, reps_pool);
         }
 
@@ -2895,11 +2895,11 @@ write_final_rev(svn_fs_x__id_t *new_id_p
           && svn_fs_x__get_revnum(noderev->prop_rep->id.change_set) == rev)
         {
           /* Add new property reps to hash and on-disk cache. */
-          representation_t *copy
+          svn_fs_x__representation_t *copy
             = svn_fs_x__rep_copy(noderev->prop_rep, reps_pool);
 
           SVN_ERR_ASSERT(reps_to_cache && reps_pool);
-          APR_ARRAY_PUSH(reps_to_cache, representation_t *) = copy;
+          APR_ARRAY_PUSH(reps_to_cache, svn_fs_x__representation_t *) = copy;
 
           apr_hash_set(reps_hash,
                         copy->sha1_digest,
@@ -3389,7 +3389,7 @@ commit_body(void *baton, apr_pool_t *poo
   return SVN_NO_ERROR;
 }
 
 /* Add the representations in REPS_TO_CACHE (an array of representation_t *)
  * to the rep-cache database of FS. */
 static svn_error_t *
 write_reps_to_cache(svn_fs_t *fs,
@@ -3400,7 +3400,7 @@ write_reps_to_cache(svn_fs_t *fs,
 
   for (i = 0; i < reps_to_cache->nelts; i++)
     {
-      representation_t *rep = APR_ARRAY_IDX(reps_to_cache, i, representation_t *);
+      svn_fs_x__representation_t *rep = APR_ARRAY_IDX(reps_to_cache, i, svn_fs_x__representation_t *);
 
       /* FALSE because we don't care if another parallel commit happened to
        * collide with us.  (Non-parallel collisions will not be detected.) */
@@ -3425,7 +3425,7 @@ svn_fs_x__commit(svn_revnum_t *new_rev_p
 
   if (ffd->rep_sharing_allowed)
     {
-      cb.reps_to_cache = apr_array_make(pool, 5, sizeof(representation_t *));
+      cb.reps_to_cache = apr_array_make(pool, 5, sizeof(svn_fs_x__representation_t *));
       cb.reps_hash = apr_hash_make(pool);
       cb.reps_pool = pool;
     }
@@ -3389,7 +3389,7 @@ commit_body(void *baton, apr_pool_t *poo
 }
 
-/* Add the representations in REPS_TO_CACHE (an array of representation_t *)
+/* Add the representations in REPS_TO_CACHE (an array of svn_fs_x__representation_t *)
  * to the rep-cache database of FS. */
 static svn_error_t *

Modified: subversion/trunk/subversion/libsvn_fs_x/verify.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_fs_x/verify.c?rev=1649050&r1=1649049&r2=1649050&view=diff
==============================================================================